pub struct Client { /* private fields */ }Implementations
Sourceimpl Client
impl Client
pub fn new() -> Self
pub fn set_cache_memory(&mut self)
pub fn disable_caching(&mut self)
pub fn set_cache_redis(&mut self, redis_client: Client)
Sourcepub async fn get_manifest_url(
&self,
url: &Url,
image: &Image,
) -> Result<Response, Error>
pub async fn get_manifest_url( &self, url: &Url, image: &Image, ) -> Result<Response, Error>
Returns the manifest for the given URL and image.
Errors
Returns an error if the request fails. Returns an error if the response body is not valid JSON. Returns an error if the response body is not a valid manifest. Returns an error if the response status is not successful.
Sourcepub async fn get_manifest(&self, image: &Image) -> Result<Response, Error>
pub async fn get_manifest(&self, image: &Image) -> Result<Response, Error>
Errors
Returns an error if the request fails. Returns an error if the response body is not valid JSON. Returns an error if the response body is not a valid manifest. Returns an error if the response status is not successful.